@@ -21,8 +21,8 @@ use Wallabag\UserBundle\Entity\User;
  */
 class Config
 {
-    const REDIRECT_TO_HOMEPAGE = 0;
-    const REDIRECT_TO_CURRENT_PAGE = 1;
+    public const REDIRECT_TO_HOMEPAGE = 0;
+    public const REDIRECT_TO_CURRENT_PAGE = 1;
 
     /**
      * @var int
@@ -35,14 +35,6 @@ class Config
      */
     private $id;
 
-    /**
-     * @var string
-     *
-     * @Assert\NotBlank()
-     * @ORM\Column(name="theme", type="string", nullable=false)
-     */
-    private $theme;
-
     /**
      * @var int
      *
@@ -125,6 +117,15 @@ class Config
      */
     private $listMode;
 
+    /**
+     * @var int
+     *
+     * @ORM\Column(name="display_thumbnails", type="integer", nullable=true, options={"default" = 1})
+     *
+     * @Groups({"config_api"})
+     */
+    private $displayThumbnails;
+
     /**
      * @ORM\OneToOne(targetEntity="Wallabag\UserBundle\Entity\User", inversedBy="config")
      */
@@ -162,30 +163,6 @@ class Config
         return $this->id;
     }
 
-    /**
-     * Set theme.
-     *
-     * @param string $theme
-     *
-     * @return Config
-     */
-    public function setTheme($theme)
-    {
-        $this->theme = $theme;
-
-        return $this;
-    }
-
-    /**
-     * Get theme.
-     *
-     * @return string
-     */
-    public function getTheme()
-    {
-        return $this->theme;
-    }
-
     /**
      * Set itemsPerPage.
      *
@@ -394,6 +371,24 @@ class Config
         return $this;
     }
 
+    /**
+     * @return bool
+     */
+    public function getDisplayThumbnails(): ?bool
+    {
+        return $this->displayThumbnails;
+    }
+
+    /**
+     * @return Config
+     */
+    public function setDisplayThumbnails(bool $displayThumbnails)
+    {
+        $this->displayThumbnails = $displayThumbnails;
+
+        return $this;
+    }
+
     /**
      * @return Config
      */
